@@ -4,7 +4,8 @@ api_settings = {
             "accept": "application/json",
             "Content-type": "application/x-www-form-urlencoded"
         },
-        "url": ":4443/v5/Token"
+        "url": ":4443/v5/Token",
+        "api_version": "v5"
     },
     "aws": {
         "headers": {
@@ -12,7 +13,11 @@ api_settings = {
             "Content-type": "application/x-www-form-urlencoded",
             "x-api-version": "1.2-rev0"
         },
-        "url": ":11005/api/v1/token"
+        "url": ":11005/api/v1/token",
+        "api_version": "v1"
+    },
+    "ent_man": {
+        "url": ":9398/api/sessionMngr/?v=latest"
     },
     "vbr": {
         "headers": {
@@ -20,14 +25,16 @@ api_settings = {
             "Content-type": "application/x-www-form-urlencoded",
             "x-api-version": "1.0-rev2"
         },
-        "url": ":9419/api/oauth2/token"
+        "url": ":9419/api/oauth2/token",
+        "api_version": "v1"
     },
     "azure": {
         "headers": {
             "accept": "application/json",
             "Content-type": "application/x-www-form-urlencoded"
         },
-        "url": "/api/oauth2/token"
+        "url": "/api/oauth2/token",
+        "api_version": "v3"
     },
     "gcp": {
         "headers": {
@@ -35,6 +42,7 @@ api_settings = {
             "Content-type": "application/x-www-form-urlencoded",
             "x-api-version": "1.0-rev0"
         },
-        "url": ":13140/api/v1/token"
+        "url": ":13140/api/v1/token",
+        "api_version": "v1"
     }
 }
\ No newline at end of file
